==> mosaicml_cli-0.2.2-py3-none-any.whl: mcli/models/mcli_integration.py <==
""" Implements MCLI Integrations """
from __future__ import annotations

from abc import ABC, abstractmethod
from dataclasses import asdict, dataclass
from typing import Any, Dict, Optional, Type

import yaml

from mcli.serverside.job.mcli_k8s_job import MCLIK8sJob
from mcli.utils.utils_serializable_dataclass import SerializableDataclass, T_SerializableDataclass
from mcli.utils.utils_types import CommonEnum


class IntegrationType(CommonEnum):
    """ Enum for Types of Setup Items Allowed """
    wandb = 'wandb'
    git_repo = 'git_repo'
    apt_packages = 'apt_packages'
    pip_packages = 'pip_packages'


@dataclass
class MCLIIntegration(SerializableDataclass, ABC):
    """
    The Base Integration Class for MCLI SetupItems

    SetupItems can not nest other SerializableDataclass objects
    """

    integration_type: IntegrationType

    @abstractmethod
    def add_to_job(self, kubernetes_job: MCLIK8sJob) -> bool:
        """Add a integration to a job
        """

    @classmethod
    def from_dict(cls: Type[T_SerializableDataclass], data: Dict[str, Any]) -> T_SerializableDataclass:
        # Make a copy to avoid mutating the original run input
        integration_data = data.copy()
        integration_type = integration_data.get('integration_type', None)
        if not integration_type:
            raise ValueError(f'No `integration_type` found for integration with data: \n{yaml.dump(integration_data)}')

        integration_type: IntegrationType = IntegrationType.ensure_enum(integration_type)
        integration_data['integration_type'] = integration_type

        # pylint: disable-next=import-outside-toplevel
        from mcli.objects.integrations import (MCLIAptPackagesIntegration, MCLIGitRepoIntegration,
                                               MCLIPipPackagesIntegration, MCLIWandBIntegration)
        integration: Optional[MCLIIntegration] = None
        if integration_type == IntegrationType.wandb:
            integration = MCLIWandBIntegration(**integration_data)
        elif integration_type == IntegrationType.git_repo:
            integration = MCLIGitRepoIntegration(**integration_data)
        elif integration_type == IntegrationType.apt_packages:
            integration = MCLIAptPackagesIntegration(**integration_data)
        elif integration_type == IntegrationType.pip_packages:
            integration = MCLIPipPackagesIntegration(**integration_data)
        else:
            raise NotImplementedError(f'Setup Item of type: { integration_type } not supported yet')
        assert isinstance(integration, MCLIIntegration)
        return integration  # type: ignore

    def __str__(self) -> str:
        data = asdict(self)
        del data['integration_type']
        return f'Integration: {self.integration_type.value}' + f'\n{ yaml.dump( data ) }'

==> mosaicml_cli-0.2.4-py3-none-any.whl: mcli/models/mcli_integration.py <==
""" Implements MCLI Integrations """
from __future__ import annotations

from abc import ABC, abstractmethod
from dataclasses import asdict, dataclass
from typing import Any, Dict, Optional, Type

import yaml

from mcli.serverside.job.mcli_k8s_job import MCLIK8sJob
from mcli.utils.utils_serializable_dataclass import SerializableDataclass, T_SerializableDataclass
from mcli.utils.utils_types import CommonEnum


class IntegrationType(CommonEnum):
    """ Enum for Types of Setup Items Allowed """
    wandb = 'wandb'
    git_repo = 'git_repo'
    apt_packages = 'apt_packages'
    pip_packages = 'pip_packages'
    local = 'local'


@dataclass
class MCLIIntegration(SerializableDataclass, ABC):
    """
    The Base Integration Class for MCLI SetupItems

    SetupItems can not nest other SerializableDataclass objects
    """

    integration_type: IntegrationType

    @abstractmethod
    def add_to_job(self, kubernetes_job: MCLIK8sJob) -> bool:
        """Add a integration to a job
        """

    @property
    def build_docker(self) -> bool:
        """If True, will add the integration in docker and will not add directly to the job
        """
        try:
            return self._build_docker
        except AttributeError:
            self._build_docker = False
            return self._build_docker

    @build_docker.setter
    def build_docker(self, val: bool) -> None:
        self._build_docker = val

    def build_to_docker(self) -> bool:
        """Add integration to docker image
        """
        raise NotImplementedError()

    @classmethod
    def from_dict(cls: Type[T_SerializableDataclass],
                  data: Dict[str, Any],
                  build_docker: bool = False) -> T_SerializableDataclass:
        # Make a copy to avoid mutating the original run input
        integration_data = data.copy()
        integration_type = integration_data.get('integration_type', None)

        if not integration_type:
            raise ValueError(f'No `integration_type` found for integration with data: \n{yaml.dump(integration_data)}')

        integration_type: IntegrationType = IntegrationType.ensure_enum(integration_type)
        integration_data['integration_type'] = integration_type

        # pylint: disable-next=import-outside-toplevel
        from mcli.objects.integrations import (MCLIAptPackagesIntegration, MCLIGitRepoIntegration, MCLILocalIntegration,
                                               MCLIPipPackagesIntegration, MCLIWandBIntegration)
        integration: Optional[MCLIIntegration] = None
        if integration_type == IntegrationType.wandb:
            integration = MCLIWandBIntegration(**integration_data)
        elif integration_type == IntegrationType.git_repo:
            integration = MCLIGitRepoIntegration(**integration_data)
        elif integration_type == IntegrationType.apt_packages:
            integration = MCLIAptPackagesIntegration(**integration_data)
        elif integration_type == IntegrationType.pip_packages:
            integration = MCLIPipPackagesIntegration(**integration_data)
        elif integration_type == IntegrationType.local:
            integration = MCLILocalIntegration(**integration_data)
            # docker build only supported for local for now
            integration.build_docker = build_docker
        else:
            raise NotImplementedError(f'Setup Item of type: { integration_type } not supported yet')
        assert isinstance(integration, MCLIIntegration)

        return integration  # type: ignore

    def __str__(self) -> str:
        data = asdict(self)
        del data['integration_type']
        return f'Integration: {self.integration_type.value}' + f'\n{ yaml.dump( data ) }'
